@@ -2,8 +2,6 @@ import json
 import pandas as pd
 from sqlalchemy import create_engine
 
-from U0.bgutils.bgutils.entity import entSftpFile
-
 
 class mysqlUtil:
     __mysql_username = 'test'
@@ -13,7 +11,10 @@ class mysqlUtil:
     __port = 53306
     __db = 'test'
     def __init__(self):
-        # 初始化数据库连接,使用pymysql库
+        self.OpenDB(self.__db)
+
+    def OpenDB(self,dbname):
+        self.__db = dbname
         self.engine = create_engine(
             'mysql+pymysql://{}:{}@{}:{}/{}'.format(self.__mysql_username,
                                                     self.__mysql_password,
@@ -21,6 +22,7 @@ class mysqlUtil:
                                                     self.__port,
                                                     self.__db))
 
+
     # 查询mysql数据库
     def query(self, sql):
         df = pd.read_sql_query(sql, self.engine)
@@ -41,9 +43,20 @@ class mysqlUtil:
         return None
 
     #添加上传文件记录
-    def sftp_file_ins(self,ent:entSftpFile):
-        # strSql="INSERT INTO test.sftp_files (filename,url,stud) VALUES ('"+ent.filename+ \
-        #        "','" + ent.url +"','" + ent.stud +"')"
-        strSql="INSERT INTO test.sftp_files (filename,url,stud) VALUES ('111','111','111')"
-        self.engine.execute(str)
-        pass
+    def sftp_file_ins(self,filename,url,stud):
+        try:
+            df = pd.DataFrame(columns=['filename','url','stud'])
+            # print(df)
+            row1=pd.DataFrame({'filename':filename,'url':url,'stud':stud}, index=[1])
+            # print(row1)
+            df=df.append(row1,ignore_index=True)
+            # print(df)
+            df.to_sql("sftp_files", self.engine, if_exists='append', index=False)  # 'sftp_files'
+
+        except Exception as ex:
+            print("日志记录出现如下异常%s" % ex)
+
+    def process_item(self, item, tblname):
+        data = pd.DataFrame(dict(item),index=[0])
+        data.to_sql(tblname, self.engine, if_exists='append', index=False) #'taobao_data'
+        return item
\ No newline at end of file
